require "gooi"

local gr = love.graphics
local mo = love.mouse

function love.load()
    cw = 200
    ch = 150
    sx = gr.getWidth() / cw
    sy = gr.getHeight() / ch

    gooi.setStyle({
        showBorder = false,
        font = gr.newFont("fonts/smallest_pixel-7.ttf", 10),
        tooltipFont = gr.newFont("fonts/smallest_pixel-7.ttf", 10),
    })
    gooi.roughShapes()
    gooi.desktopMode()

    canvas = gr.newCanvas(cw, ch)
    canvas:setFilter("nearest", "nearest")

    gooi.setCanvas(canvas)
    p = gooi.newPanel({x = 0, y = 0, w = cw, h = ch, layout = "grid 6x3"})
        :setRowspan(5, 1, 2)
        :setRowspan(5, 2, 2)
    --p.layout.debug = true

    local imgbg = "imgs/testBgComp.png"

    p:add(gooi.newLabel({text = "label", icon = "imgs/ship.png"}))
    p:add(gooi.newButton({text = "button"}):setBGImage(imgbg))
    p:add(gooi.newSlider():setBGImage(imgbg))
    p:add(gooi.newCheck({text = "check"}):setBGImage(imgbg))
    p:add(gooi.newRadio({text = "rad 1", radioGroup = "g1"}):setBGImage(imgbg):select())
    p:add(gooi.newRadio({text = "rad 2", radioGroup = "g1"}))
    p:add(gooi.newText({text = "abc"}):setBGImage(imgbg))
    p:add(gooi.newBar({value = 0}):increaseAt(0.1):setBGImage(imgbg))
    p:add(gooi.newSpinner():setBGImage(imgbg))
    p:add(gooi.newButton({text = "modal"})
        :onRelease(function(c)
            gooi.confirm({
                text = "hello!",
                ok = function() gooi.alert({text = "fine!"}) end,
                cancel = function() gooi.alert({text = "too bad :("}) end,
                okText = "yes!",
                cancelText = "no!"
            })
        end)
        :bg("#ff8800"))
    p:add(gooi.newButton({text = "tooltip"}):setTooltip("this is a tooltip"))

    p:add(gooi.newJoy():setBGImage(imgbg), "5,1")
    p:add(gooi.newKnob():setBGImage(imgbg), "5,2")
    --[[
    
    gooi.newSlider({w = 30, h = 90}):vertical()
    ]]
end

function love.update(dt)
    gooi.update(dt)
end

function love.draw()
    gr.setColor(255, 255, 255)
    gr.setCanvas(canvas)
    gr.clear(16, 32, 32)
    gooi.draw()

    gr.setCanvas()
    gr.setColor(255, 255, 255)
    gr.draw(canvas, 0, 0, 0, sx, sy)

    gr.print("FPS: "..love.timer.getFPS())
end

function love.mousereleased(x, y, button)       gooi.released() end
function love.mousemoved(x, y, dx, dy, istouch) gooi.moved() end
function love.mousepressed(x, y, button)        gooi.pressed() end

function love.textinput(text)
    gooi.textinput(text)
end
function love.keypressed(key, scancode, isrepeat)
    gooi.keypressed(key, scancode, isrepeat)
    if key == "escape" then
        quit()
    end
end
function love.keyreleased(key, scancode)
    gooi.keyreleased(key, scancode)
end

function quit()
    love.event.quit()
end